From f6a11e0de1ab950b42679d6be9dc0f3ac86c3399 Mon Sep 17 00:00:00 2001
From: Sandro Santilli <strk@kbt.io>
Date: Mon, 7 Nov 2016 17:24:59 +0100
Subject: [PATCH] More MixedCase consts

---
 models/admin.go         |  6 ++---
 models/git_diff.go      | 58 ++++++++++++++++++++---------------------
 models/git_diff_test.go |  4 +--
 models/issue.go         | 26 +++++++++---------
 routers/repo/issue.go   | 10 +++----
 routers/user/home.go    |  8 +++---
 6 files changed, 56 insertions(+), 56 deletions(-)

diff --git a/models/git_diff.go b/models/git_diff.go
index 704a4a382..ffe9d9e81 100644
--- a/models/git_diff.go
+++ b/models/git_diff.go
@@ -31,18 +31,18 @@ import (
 type DiffLineType uint8
 
 const (
-	DIFF_LINE_PLAIN DiffLineType = iota + 1
-	DIFF_LINE_ADD
-	DIFF_LINE_DEL
+	DiffLinePlain DiffLineType = iota + 1
+	DiffLineAdd
+	DiffLineDel
 	DIFF_LINE_SECTION
 )
 
 type DiffFileType uint8
 
 const (
-	DIFF_FILE_ADD DiffFileType = iota + 1
-	DIFF_FILE_CHANGE
-	DIFF_FILE_DEL
+	DiffFileAdd DiffFileType = iota + 1
+	DiffFileChange
+	DiffFileDel
 	DIFF_FILE_RENAME
 )
 
@@ -73,19 +73,19 @@ func diffToHTML(diffs []diffmatchpatch.Diff, lineType DiffLineType) template.HTM
 
 	// Reproduce signs which are cutted for inline diff before.
 	switch lineType {
-	case DIFF_LINE_ADD:
+	case DiffLineAdd:
 		buf.WriteByte('+')
-	case DIFF_LINE_DEL:
+	case DiffLineDel:
 		buf.WriteByte('-')
 	}
 
 	for i := range diffs {
 		switch {
-		case diffs[i].Type == diffmatchpatch.DiffInsert && lineType == DIFF_LINE_ADD:
+		case diffs[i].Type == diffmatchpatch.DiffInsert && lineType == DiffLineAdd:
 			buf.Write(addedCodePrefix)
 			buf.WriteString(html.EscapeString(diffs[i].Text))
 			buf.Write(codeTagSuffix)
-		case diffs[i].Type == diffmatchpatch.DiffDelete && lineType == DIFF_LINE_DEL:
+		case diffs[i].Type == diffmatchpatch.DiffDelete && lineType == DiffLineDel:
 			buf.Write(removedCodePrefix)
 			buf.WriteString(html.EscapeString(diffs[i].Text))
 			buf.Write(codeTagSuffix)
@@ -109,9 +109,9 @@ func (diffSection *DiffSection) GetLine(lineType DiffLineType, idx int) *DiffLin
 LOOP:
 	for _, diffLine := range diffSection.Lines {
 		switch diffLine.Type {
-		case DIFF_LINE_ADD:
+		case DiffLineAdd:
 			addCount++
-		case DIFF_LINE_DEL:
+		case DiffLineDel:
 			delCount++
 		default:
 			if matchDiffLine != nil {
@@ -123,11 +123,11 @@ LOOP:
 		}
 
 		switch lineType {
-		case DIFF_LINE_DEL:
+		case DiffLineDel:
 			if diffLine.RightIdx == 0 && diffLine.LeftIdx == idx-difference {
 				matchDiffLine = diffLine
 			}
-		case DIFF_LINE_ADD:
+		case DiffLineAdd:
 			if diffLine.LeftIdx == 0 && diffLine.RightIdx == idx+difference {
 				matchDiffLine = diffLine
 			}
@@ -159,15 +159,15 @@ func (diffSection *DiffSection) GetComputedInlineDiffFor(diffLine *DiffLine) tem
 
 	// try to find equivalent diff line. ignore, otherwise
 	switch diffLine.Type {
-	case DIFF_LINE_ADD:
-		compareDiffLine = diffSection.GetLine(DIFF_LINE_DEL, diffLine.RightIdx)
+	case DiffLineAdd:
+		compareDiffLine = diffSection.GetLine(DiffLineDel, diffLine.RightIdx)
 		if compareDiffLine == nil {
 			return template.HTML(html.EscapeString(diffLine.Content))
 		}
 		diff1 = compareDiffLine.Content
 		diff2 = diffLine.Content
-	case DIFF_LINE_DEL:
-		compareDiffLine = diffSection.GetLine(DIFF_LINE_ADD, diffLine.LeftIdx)
+	case DiffLineDel:
+		compareDiffLine = diffSection.GetLine(DiffLineAdd, diffLine.LeftIdx)
 		if compareDiffLine == nil {
 			return template.HTML(html.EscapeString(diffLine.Content))
 		}
@@ -264,7 +264,7 @@ func ParsePatch(maxLines, maxLineCharacteres, maxFiles int, reader io.Reader) (*
 
 		switch {
 		case line[0] == ' ':
-			diffLine := &DiffLine{Type: DIFF_LINE_PLAIN, Content: line, LeftIdx: leftLine, RightIdx: rightLine}
+			diffLine := &DiffLine{Type: DiffLinePlain, Content: line, LeftIdx: leftLine, RightIdx: rightLine}
 			leftLine++
 			rightLine++
 			curSection.Lines = append(curSection.Lines, diffLine)
@@ -289,14 +289,14 @@ func ParsePatch(maxLines, maxLineCharacteres, maxFiles int, reader io.Reader) (*
 		case line[0] == '+':
 			curFile.Addition++
 			diff.TotalAddition++
-			diffLine := &DiffLine{Type: DIFF_LINE_ADD, Content: line, RightIdx: rightLine}
+			diffLine := &DiffLine{Type: DiffLineAdd, Content: line, RightIdx: rightLine}
 			rightLine++
 			curSection.Lines = append(curSection.Lines, diffLine)
 			continue
 		case line[0] == '-':
 			curFile.Deletion++
 			diff.TotalDeletion++
-			diffLine := &DiffLine{Type: DIFF_LINE_DEL, Content: line, LeftIdx: leftLine}
+			diffLine := &DiffLine{Type: DiffLineDel, Content: line, LeftIdx: leftLine}
 			if leftLine > 0 {
 				leftLine++
 			}
@@ -330,7 +330,7 @@ func ParsePatch(maxLines, maxLineCharacteres, maxFiles int, reader io.Reader) (*
 			curFile = &DiffFile{
 				Name:     a,
 				Index:    len(diff.Files) + 1,
-				Type:     DIFF_FILE_CHANGE,
+				Type:     DiffFileChange,
 				Sections: make([]*DiffSection, 0, 10),
 			}
 			diff.Files = append(diff.Files, curFile)
@@ -354,13 +354,13 @@ func ParsePatch(maxLines, maxLineCharacteres, maxFiles int, reader io.Reader) (*
 
 				switch {
 				case strings.HasPrefix(line, "new file"):
-					curFile.Type = DIFF_FILE_ADD
+					curFile.Type = DiffFileAdd
 					curFile.IsCreated = true
 				case strings.HasPrefix(line, "deleted"):
-					curFile.Type = DIFF_FILE_DEL
+					curFile.Type = DiffFileDel
 					curFile.IsDeleted = true
 				case strings.HasPrefix(line, "index"):
-					curFile.Type = DIFF_FILE_CHANGE
+					curFile.Type = DiffFileChange
 				case strings.HasPrefix(line, "similarity index 100%"):
 					curFile.Type = DIFF_FILE_RENAME
 					curFile.IsRenamed = true
@@ -459,8 +459,8 @@ func GetDiffRange(repoPath, beforeCommitID, afterCommitID string, maxLines, maxL
 type RawDiffType string
 
 const (
-	RAW_DIFF_NORMAL RawDiffType = "diff"
-	RAW_DIFF_PATCH  RawDiffType = "patch"
+	RawDiffNormal RawDiffType = "diff"
+	RawDiffPatch  RawDiffType = "patch"
 )
 
 // GetRawDiff dumps diff results of repository in given commit ID to io.Writer.
@@ -478,14 +478,14 @@ func GetRawDiff(repoPath, commitID string, diffType RawDiffType, writer io.Write
 
 	var cmd *exec.Cmd
 	switch diffType {
-	case RAW_DIFF_NORMAL:
+	case RawDiffNormal:
 		if commit.ParentCount() == 0 {
 			cmd = exec.Command("git", "show", commitID)
 		} else {
 			c, _ := commit.Parent(0)
 			cmd = exec.Command("git", "diff", "-M", c.ID.String(), commitID)
 		}
-	case RAW_DIFF_PATCH:
+	case RawDiffPatch:
 		if commit.ParentCount() == 0 {
 			cmd = exec.Command("git", "format-patch", "--no-signature", "--stdout", "--root", commitID)
 		} else {
diff --git a/models/git_diff_test.go b/models/git_diff_test.go
index 7f390adb3..cf98f6539 100644
--- a/models/git_diff_test.go
+++ b/models/git_diff_test.go
@@ -24,12 +24,12 @@ func TestDiffToHTML(t *testing.T) {
 		dmp.Diff{dmp.DiffInsert, "bar"},
 		dmp.Diff{dmp.DiffDelete, " baz"},
 		dmp.Diff{dmp.DiffEqual, " biz"},
-	}, DIFF_LINE_ADD))
+	}, DiffLineAdd))
 
 	assertEqual(t, "-foo <span class=\"removed-code\">bar</span> biz", diffToHTML([]dmp.Diff{
 		dmp.Diff{dmp.DiffEqual, "foo "},
 		dmp.Diff{dmp.DiffDelete, "bar"},
 		dmp.Diff{dmp.DiffInsert, " baz"},
 		dmp.Diff{dmp.DiffEqual, " biz"},
-	}, DIFF_LINE_DEL))
+	}, DiffLineDel))
 }
diff --git a/models/issue.go b/models/issue.go
index a331883c4..6078f53f2 100644
--- a/models/issue.go
+++ b/models/issue.go
@@ -1005,9 +1005,9 @@ func GetIssueUserPairsByMode(uid, rid int64, isClosed bool, page, filterMode int
 	}
 
 	switch filterMode {
-	case FM_ASSIGN:
+	case FilterModeAssign:
 		sess.And("is_assigned=?", true)
-	case FM_CREATE:
+	case FilterModeCreate:
 		sess.And("is_poster=?", true)
 	default:
 		return ius, nil
@@ -1070,10 +1070,10 @@ type IssueStats struct {
 
 // Filter modes.
 const (
-	FM_ALL = iota
-	FM_ASSIGN
-	FM_CREATE
-	FM_MENTION
+	FilterModeAll = iota
+	FilterModeAssign
+	FilterModeCreate
+	FilterModeMention
 )
 
 func parseCountResult(results []map[string][]byte) int64 {
@@ -1122,7 +1122,7 @@ func GetIssueStats(opts *IssueStatsOptions) *IssueStats {
 	}
 
 	switch opts.FilterMode {
-	case FM_ALL, FM_ASSIGN:
+	case FilterModeAll, FilterModeAssign:
 		stats.OpenCount, _ = countSession(opts).
 			And("is_closed = ?", false).
 			Count(&Issue{})
@@ -1130,7 +1130,7 @@ func GetIssueStats(opts *IssueStatsOptions) *IssueStats {
 		stats.ClosedCount, _ = countSession(opts).
 			And("is_closed = ?", true).
 			Count(&Issue{})
-	case FM_CREATE:
+	case FilterModeCreate:
 		stats.OpenCount, _ = countSession(opts).
 			And("poster_id = ?", opts.UserID).
 			And("is_closed = ?", false).
@@ -1140,7 +1140,7 @@ func GetIssueStats(opts *IssueStatsOptions) *IssueStats {
 			And("poster_id = ?", opts.UserID).
 			And("is_closed = ?", true).
 			Count(&Issue{})
-	case FM_MENTION:
+	case FilterModeMention:
 		stats.OpenCount, _ = countSession(opts).
 			Join("INNER", "issue_user", "issue.id = issue_user.issue_id").
 			And("issue_user.uid = ?", opts.UserID).
@@ -1186,10 +1186,10 @@ func GetUserIssueStats(repoID, uid int64, repoIDs []int64, filterMode int, isPul
 	closedCountSession := countSession(true, isPull, repoID, repoIDs)
 
 	switch filterMode {
-	case FM_ASSIGN:
+	case FilterModeAssign:
 		openCountSession.And("assignee_id = ?", uid)
 		closedCountSession.And("assignee_id = ?", uid)
-	case FM_CREATE:
+	case FilterModeCreate:
 		openCountSession.And("poster_id = ?", uid)
 		closedCountSession.And("poster_id = ?", uid)
 	}
@@ -1214,10 +1214,10 @@ func GetRepoIssueStats(repoID, uid int64, filterMode int, isPull bool) (numOpen
 	closedCountSession := countSession(true, isPull, repoID)
 
 	switch filterMode {
-	case FM_ASSIGN:
+	case FilterModeAssign:
 		openCountSession.And("assignee_id = ?", uid)
 		closedCountSession.And("assignee_id = ?", uid)
-	case FM_CREATE:
+	case FilterModeCreate:
 		openCountSession.And("poster_id = ?", uid)
 		closedCountSession.And("poster_id = ?", uid)
 	}
diff --git a/routers/repo/issue.go b/routers/repo/issue.go
index 8e8328c7e..9dff643ea 100644
--- a/routers/repo/issue.go
+++ b/routers/repo/issue.go
@@ -126,16 +126,16 @@ func Issues(ctx *context.Context) {
 		assigneeID = ctx.QueryInt64("assignee")
 		posterID   int64
 	)
-	filterMode := models.FM_ALL
+	filterMode := models.FilterModeAll
 	switch viewType {
 	case "assigned":
-		filterMode = models.FM_ASSIGN
+		filterMode = models.FilterModeAssign
 		assigneeID = ctx.User.ID
 	case "created_by":
-		filterMode = models.FM_CREATE
+		filterMode = models.FilterModeCreate
 		posterID = ctx.User.ID
 	case "mentioned":
-		filterMode = models.FM_MENTION
+		filterMode = models.FilterModeMention
 	}
 
 	var uid int64 = -1
@@ -179,7 +179,7 @@ func Issues(ctx *context.Context) {
 		MilestoneID: milestoneID,
 		Page:        pager.Current(),
 		IsClosed:    isShowClosed,
-		IsMention:   filterMode == models.FM_MENTION,
+		IsMention:   filterMode == models.FilterModeMention,
 		IsPull:      isPullList,
 		Labels:      selectLabels,
 		SortType:    sortType,
diff --git a/routers/user/home.go b/routers/user/home.go
index fb079546e..bc22d86ea 100644
--- a/routers/user/home.go
+++ b/routers/user/home.go
@@ -172,7 +172,7 @@ func Issues(ctx *context.Context) {
 	var (
 		viewType   string
 		sortType   = ctx.Query("sort")
-		filterMode = models.FM_ALL
+		filterMode = models.FilterModeAll
 		assigneeID int64
 		posterID   int64
 	)
@@ -187,10 +187,10 @@ func Issues(ctx *context.Context) {
 
 		switch viewType {
 		case "assigned":
-			filterMode = models.FM_ASSIGN
+			filterMode = models.FilterModeAssign
 			assigneeID = ctxUser.ID
 		case "created_by":
-			filterMode = models.FM_CREATE
+			filterMode = models.FilterModeCreate
 			posterID = ctxUser.ID
 		}
 	}
@@ -235,7 +235,7 @@ func Issues(ctx *context.Context) {
 			allCount += repo.NumOpenIssues
 		}
 
-		if filterMode != models.FM_ALL {
+		if filterMode != models.FilterModeAll {
 			// Calculate repository issue count with filter mode.
 			numOpen, numClosed := repo.IssueStats(ctxUser.ID, filterMode, isPullList)
 			repo.NumOpenIssues, repo.NumClosedIssues = int(numOpen), int(numClosed)
diff --git a/models/admin.go b/models/admin.go
index 3f17c2fda..dab92863a 100644
--- a/models/admin.go
+++ b/models/admin.go
@@ -22,7 +22,7 @@ import (
 type NoticeType int
 
 const (
-	NOTICE_REPOSITORY NoticeType = iota + 1
+	NoticeRepository NoticeType = iota + 1
 )
 
 // Notice represents a system notice for admin.
@@ -65,9 +65,9 @@ func CreateNotice(tp NoticeType, desc string) error {
 	return err
 }
 
 // CreateRepositoryNotice creates new system notice with type NOTICE_REPOSITORY.
 func CreateRepositoryNotice(desc string) error {
-	return CreateNotice(NOTICE_REPOSITORY, desc)
+	return CreateNotice(NoticeRepository, desc)
 }
 
 // RemoveAllWithNotice removes all directories in given path and
@@ -65,9 +65,9 @@ func CreateNotice(tp NoticeType, desc string) error {
 }
 
-// CreateRepositoryNotice creates new system notice with type NOTICE_REPOSITORY.
+// CreateRepositoryNotice creates new system notice with type NoticeRepository.
 func CreateRepositoryNotice(desc string) error {